==> dedit_0.5.11.tar.gz: dedit-0.5.11/src/callbacks.h <==
/* $Id: callbacks.h,v 1.2 1999/11/24 13:12:16 kitame Exp $

  Functions for Mainly use.

  Copyright (C) 1999  Takuo KITAME

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License with
  the Debian GNU/Linux distribution in file /usr/doc/copyright/GPL;
  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
  Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __CALLBACKS_H__
#define __CALLBACKS_H__

#include <gtk/gtk.h>
#include <gdk/gdk.h>

#include <gnome.h>

#include "dedit.h"

gint dedit_new_document(GtkWidget *widget, gpointer data);

void fixed_cb(GtkWidget * w, gpointer data);

void add_doc_cb(GtkWidget *widget, gpointer data);
void remove_cb(GtkWidget *widget);
void quit_cb(GtkWidget *w);

gint remove_child_handler(GnomeMDI *mdi, GnomeMDIChild *child);
void cleanup_cb(GnomeMDI *mdi);
void child_changed_cb(GnomeMDI *mdi, GnomeApp *app);

void dedit_cut_cb(GtkWidget *widget, gpointer data);
void dedit_copy_cb(GtkWidget *widget, gpointer data);
void dedit_paste_cb(GtkWidget *widget, gpointer data);
void dedit_select_all_cb(GtkWidget *widget, gpointer data);

void text_changed_cb (GtkWidget *widget, gpointer data);

void app_created_cb(GnomeMDI *mdi, GnomeApp *app);
void drop_cb (GtkWidget *widget,
              GdkDragContext   *context,
              gint              x,
              gint              y,
              GtkSelectionData *selection_data,
              guint             info,
              guint             time);

#endif

==> dedit_0.6.2.3.tar.gz: dedit-0.6.2.3/src/callbacks.h <==
/* $Id: callbacks.h,v 1.1.1.1 2000/10/13 06:45:02 kitame Exp $

  Functions for Mainly use.

  Copyright (C) 1999  Takuo KITAME

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License with
  the Debian GNU/Linux distribution in file /usr/doc/copyright/GPL;
  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
  Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __CALLBACKS_H__
#define __CALLBACKS_H__

#include <gtk/gtk.h>
#include <gdk/gdk.h>

#include <gnome.h>

#include "dedit.h"

gint dedit_new_document(GtkWidget *widget, gpointer data);

void fixed_cb(GtkWidget * w, gpointer data);

void add_doc_cb(GtkWidget *widget, gpointer data);
void remove_cb(GtkWidget *widget);
void quit_cb(GtkWidget *w);

gint remove_child_handler(GnomeMDI *mdi, GnomeMDIChild *child);
void cleanup_cb(GnomeMDI *mdi);
void child_changed_cb(GnomeMDI *mdi, GnomeApp *app);

void dedit_cut_cb(GtkWidget *widget, gpointer data);
void dedit_copy_cb(GtkWidget *widget, gpointer data);
void dedit_paste_cb(GtkWidget *widget, gpointer data);
void dedit_select_all_cb(GtkWidget *widget, gpointer data);

void text_changed_cb (GtkWidget *widget, gpointer data);

void app_created_cb(GnomeMDI *mdi, GnomeApp *app);
void drop_cb (GtkWidget *widget,
              GdkDragContext   *context,
              gint              x,
              gint              y,
              GtkSelectionData *selection_data,
              guint             info,
              guint             time);

void dedit_doc_set_font(DEdit *doc, gchar *fontname);
void dedit_doc_set_prefs_color(DEdit *doc);
void dedit_set_prefs_toolbar(void);

#endif
